@@ -139,7 +139,7 @@ class Signal(BridgeH5):
             # if lineage_location not in f:
             #     lineage_location = lineage_location.split("_")[0]
             if lineage_location not in f:
-                lineage_location = "postprocessor/lineage"
+                lineage_location = "postprocessing/lineage"
             tile_mo_da = f[lineage_location]
 
             if isinstance(tile_mo_da, h5py.Dataset):
@@ -320,7 +320,9 @@ class Signal(BridgeH5):
         with h5py.File(self.filename, "r") as f:
             picks = set()
             if path in f:
-                picks = set(zip(*[f[path + name] for name in names]))
+                picks = set(
+                    zip(*[f[path + name] for name in names if name in f[path]])
+                )
             return picks
 
     def dataset_to_df(self, f: h5py.File, path: str) -> pd.DataFrame:
