@@ -9,7 +9,7 @@ def _str_to_int(x: str or None):
     """
     Cast string as int if possible. If Nonetype return None.
     """
-    if x:
+    if x is not None:
         try:
             return int(x)
         except:
