@@ -16,9 +16,10 @@ ImageDummy is a dummy class for silent failure testing.
 import typing as t
 from abc import ABC, abstractmethod, abstractproperty
 from datetime import datetime
-from pathlib import Path, PosixPath
+from pathlib import Path
 
 import dask.array as da
+import numpy as np
 import xmltodict
 import zarr
 from dask.array.image import imread
@@ -33,34 +34,36 @@ def get_examples_dir():
     return files("aliby").parent.parent / "examples" / "tiler"
 
 
-def instatiate_image(source: t.Union[str, int, t.Dict[str, str], PosixPath]):
+def instantiate_image(
+    source: t.Union[str, int, t.Dict[str, str], Path], **kwargs
+):
     """Wrapper to instatiate the appropiate image
 
     Parameters
     ----------
-    source : t.Union[str, int, t.Dict[str, str], PosixPath]
+    source : t.Union[str, int, t.Dict[str, str], Path]
         Image identifier
 
     Examples
     --------
     image_path = "path/to/image"]
-    with instatiate_image(image_path) as img:
+    with instantiate_image(image_path) as img:
         print(imz.data, img.metadata)
 
     """
-    return dispatch_image(source)(source)
+    return dispatch_image(source)(source, **kwargs)
 
 
-def dispatch_image(source: t.Union[str, int, t.Dict[str, str], PosixPath]):
+def dispatch_image(source: t.Union[str, int, t.Dict[str, str], Path]):
     """
     Wrapper to pick the appropiate Image class depending on the source of data.
     """
-    if isinstance(source, int):
+    if isinstance(source, (int, np.int64)):
         from aliby.io.omero import Image
 
         instatiator = Image
     elif isinstance(source, dict) or (
-        isinstance(source, (str, PosixPath)) and Path(source).is_dir()
+        isinstance(source, (str, Path)) and Path(source).is_dir()
     ):
         if Path(source).suffix == ".zarr":
             instatiator = ImageZarr
@@ -81,7 +84,7 @@ class BaseLocalImage(ABC):
 
     _default_dimorder = "tczyx"
 
-    def __init__(self, path: t.Union[str, PosixPath]):
+    def __init__(self, path: t.Union[str, Path]):
         # If directory, assume contents are naturally sorted
         self.path = Path(path)
 
@@ -249,7 +252,7 @@ class ImageDir(BaseLocalImage):
     - Provides Dimorder as it is set in the filenames, or expects order during instatiation
     """
 
-    def __init__(self, path: t.Union[str, PosixPath], **kwargs):
+    def __init__(self, path: t.Union[str, Path], **kwargs):
         super().__init__(path)
         self.image_id = str(self.path.stem)
 
@@ -305,7 +308,7 @@ class ImageZarr(BaseLocalImage):
     skeletons/scripts/howto_omero/convert_clone_zarr_to_tiff.py
     """
 
-    def __init__(self, path: t.Union[str, PosixPath], **kwargs):
+    def __init__(self, path: t.Union[str, Path], **kwargs):
         super().__init__(path)
         self.set_meta()
         try:
