@@ -61,23 +61,6 @@ class ExtractorParameters(ParametersABC):
         self.sub_bg = sub_bg
         self.multichannel_ops = multichannel_ops
 
-    @staticmethod
-    def guess_from_meta(store_name: str, suffix="fast"):
-        """
-        Find the microscope name from the h5 metadata.
-
-        Parameters
-        ----------
-        store_name : str or Path
-            For a h5 file
-        suffix : str
-            Added at the end of the predicted parameter set
-        """
-        with h5py.File(store_name, "r") as f:
-            microscope = f["/"].attrs.get("microscope")
-        assert microscope, "No metadata found"
-        return "_".join((microscope, suffix))
-
     @classmethod
     def default(cls):
         return cls({})
@@ -407,8 +390,6 @@ class Extractor(StepABC):
         reduced = img
         if method is not None:
             reduced = reduce_z(img, method)
-        if reduced.shape[0] < 10:
-            print("ahoy")
         return reduced
 
     def extract_tp(
@@ -484,12 +465,6 @@ class Extractor(StepABC):
         # generate boolean masks for background as a list with one mask per trap
         bgs = np.array([])
         if self.params.sub_bg:
-            # bgs = [
-            #     ~np.sum(m, axis=0).astype(bool)
-            #     if np.any(m)
-            #     else np.zeros((tile_size, tile_size)).astype(bool)
-            #     for m in masks
-            # ]
             bgs = ~np.array(
                 list(
                     map(
